### Main page

header
body
any_cell
codecell
input_group
in_prompt
input
output_group
output_prompt
outputs (see below)
any_cell
markdowncell
any_cell
rawcell
any_cell
unknowncell
⋮
footer

### Outputs

outputs
output
execute_result
output
stream_stdout
output
stream_stderr
output
display_data
data_priority
data_pdf / data_svg / data_png / data_html / data_markdown / data_jpg / data_text / data_latex / data_javascript / data_other
output
error
traceback_line
⋮
⋮

### Extra HTML blocks

####

    basic.tpl

output
output_area_prompt
output (as above)

####

    full.tpl

header

    <head>

html_head

    </head>

### Extra Latex blocks

header
docclass
packages
definitions
title
date
author
commands
margins
body
predoc
maketitle
abstract
... other fields as above ...
postdoc
bibliography